You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@flink.apache.org by tw...@apache.org on 2022/03/17 16:52:21 UTC

[flink] branch release-1.15 updated: [FLINK-26194][table-api-java] Deprecate unused options in TableConfig

This is an automated email from the ASF dual-hosted git repository.

twalthr pushed a commit to branch release-1.15
in repository https://gitbox.apache.org/repos/asf/flink.git


The following commit(s) were added to refs/heads/release-1.15 by this push:
     new 1e33448  [FLINK-26194][table-api-java] Deprecate unused options in TableConfig
1e33448 is described below

commit 1e3344854b3bfd7b6f5498a0297ba49d55127003
Author: Marios Trivyzas <ma...@gmail.com>
AuthorDate: Thu Mar 10 11:20:52 2022 +0200

    [FLINK-26194][table-api-java] Deprecate unused options in TableConfig
    
    Deprecate `nullCheck` and `decimalContext`.
---
 .../org/apache/flink/table/api/TableConfig.java    | 31 ++++++++++++++++++----
 1 file changed, 26 insertions(+), 5 deletions(-)

diff --git a/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/api/TableConfig.java b/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/api/TableConfig.java
index 9b6de0c..7b6f859 100644
--- a/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/api/TableConfig.java
+++ b/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/api/TableConfig.java
@@ -109,8 +109,12 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
     //
     // The set() methods only impact the application-specific configuration.
 
-    /** Defines if all fields need to be checked for NULL first. */
-    private Boolean nullCheck = true;
+    /**
+     * Defines if all fields need to be checked for NULL first.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
+     */
+    @Deprecated private Boolean nullCheck = true;
 
     /** Defines the configuration of Planner for Table API and SQL queries. */
     private PlannerConfig plannerConfig = PlannerConfig.EMPTY_CONFIG;
@@ -118,8 +122,10 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
     /**
      * Defines the default context for decimal division calculation. We use Scala's default
      * MathContext.DECIMAL128.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
      */
-    private MathContext decimalContext = MathContext.DECIMAL128;
+    @Deprecated private MathContext decimalContext = MathContext.DECIMAL128;
 
     /**
      * A configuration object to hold all configuration that has been set specifically in the Table
@@ -312,12 +318,21 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
         }
     }
 
-    /** Returns the NULL check. If enabled, all fields need to be checked for NULL first. */
+    /**
+     * Returns the NULL check. If enabled, all fields need to be checked for NULL first.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
+     */
+    @Deprecated
     public Boolean getNullCheck() {
         return nullCheck;
     }
 
     /** Sets the NULL check. If enabled, all fields need to be checked for NULL first. */
     public void setNullCheck(Boolean nullCheck) {
         this.nullCheck = Preconditions.checkNotNull(nullCheck);
     }
@@ -338,7 +353,10 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
     /**
      * Returns the default context for decimal division calculation. {@link
      * java.math.MathContext#DECIMAL128} by default.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
      */
+    @Deprecated
     public MathContext getDecimalContext() {
         return decimalContext;
     }
@@ -346,7 +364,10 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
     /**
      * Sets the default context for decimal division calculation. {@link
      * java.math.MathContext#DECIMAL128} by default.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
      */
+    @Deprecated
     public void setDecimalContext(MathContext decimalContext) {
         this.decimalContext = Preconditions.checkNotNull(decimalContext);
     }
@@ -312,12 +318,21 @@ public final class TableConfig implements WritableConfig, ReadableConfig {
     }
 
-    /** Sets the NULL check. If enabled, all fields need to be checked for NULL first. */
+    /**
+     * Sets the NULL check. If enabled, all fields need to be checked for NULL first.
+     *
+     * @deprecated This option is not used anymore and will be removed in next releases.
+     */
     public void setNullCheck(Boolean nullCheck) {
         this.nullCheck = Preconditions.checkNotNull(nullCheck);